==> haskell-vec-0.5-77-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 vec
version:              0.5
visibility:           public
id:                   vec-0.5-HGlMlPHHPA7KCFQS22pkQi
key:                  vec-0.5-HGlMlPHHPA7KCFQS22pkQi
license:              BSD-3-Clause
copyright:            (c) 2017-2021 Oleg Grenrus
maintainer:           Oleg.Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/vec
synopsis:             Vec: length-indexed (sized) list
description:
    This package provides length-indexed (sized) lists, also known as vectors.

    @
    data Vec n a where
    \    VNil  :: Vec '\''Nat.Z a
    \    (:::) :: a -> Vec n a -> Vec ('\''Nat.S n) a
    @

    The functions are implemented in four flavours:

    * __naive__: with explicit recursion. It'\''s simple, constraint-less, yet slow.

    * __pull__: using @Fin n -> a@ representation, which fuses well,
    but makes some programs hard to write. And

    * __data-family__: which allows lazy pattern matching

    * __inline__: which exploits how GHC dictionary inlining works, unrolling
    recursion if the size of '\''Vec'\'' is known statically.

    As best approach depends on the application, @vec@ doesn'\''t do any magic
    transformation. Benchmark your code.

    This package uses [fin](https://hackage.haskell.org/package/fin), i.e. not @GHC.TypeLits@, for indexes.

    For @lens@ or @optics@ support see [vec-lens](https://hackage.haskell.org/package/vec-lens) and [vec-optics](https://hackage.haskell.org/package/vec-optics) packages respectively.

    See [Hasochism: the pleasure and pain of dependently typed haskell programming](https://doi.org/10.1145/2503778.2503786)
    by Sam Lindley and Conor McBride for answers to /how/ and /why/.
    Read [APLicative Programming with Naperian Functors](https://doi.org/10.1007/978-3-662-54434-1_21)
    by Jeremy Gibbons for (not so) different ones.

    === Similar packages

    * [linear](https://hackage.haskell.org/package/linear) has '\''V'\'' type,
    which uses '\''Vector'\'' from @vector@ package as backing store.
    @Vec@ is a real GADT, but tries to provide as many useful instances (upto @lens@).

    * [vector-sized](https://hackage.haskell.org/package/vector-sized)
    Great package using @GHC.TypeLits@. Current version (0.6.1.0) uses
    @finite-typelits@ and @Int@ indexes.

    * [sized-vector](https://hackage.haskell.org/package/sized-vector) depends
    on @singletons@ package. @vec@ isn'\''t light on dependencies either,
    but try to provide wide GHC support.

    * [fixed-vector](https://hackage.haskell.org/package/fixed-vector)

    * [sized](https://hackage.haskell.org/package/sized) also depends
    on a @singletons@ package. The @Sized f n a@ type is generalisation of
    @linear@'\''s @V@ for any @ListLike@.

    * [clash-prelude](https://hackage.haskell.org/package/clash-prelude)
    is a kitchen sink package, which has @CLaSH.Sized.Vector@ module.
    Also depends on @singletons@.

category:             Data, Dependent Types
abi:                  eb10e3fb72c941c6a1dc2e5f2f2582cd
exposed:              True
exposed-modules:
    Data.Vec.DataFamily.SpineStrict Data.Vec.Lazy Data.Vec.Lazy.Inline
    Data.Vec.Pull

hidden-modules:       Control.Lens.Yocto SafeCompat
import-dirs:          /usr/lib/ghc-9.2.8/site-local/vec-0.5
library-dirs:         /usr/lib/ghc-9.2.8/site-local/vec-0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vec
hs-libraries:         HSvec-0.5-HGlMlPHHPA7KCFQS22pkQi
depends:
    QuickCheck-2.14.3-GYIzHRC98oX2ojVETG14rD
    adjunctions-4.4.2-3QguUWElTVn15ZqWzSGLp7 base-4.16.4.0
    boring-0.2.1-4ay7NZ1mR0V485tuSNtr0u deepseq-1.4.6.1
    distributive-0.6.2.1-2koEeSfM3NQ4osK1XiGjL1
    fin-0.3-AuiNMYrB5Ld2eFdTSc7NJK
    hashable-1.4.4.0-7BSyPsBurXt9vEzyIgxmkb
    indexed-traversable-0.1.4-JxISWrK95Bu3Hpi02tVEsC
    semigroupoids-6.0.0.1-CiKv0Fr9KpC7HcwUSK24F2 transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-vec/html/vec.haddock
haddock-html:         /usr/share/doc/haskell-vec/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vec-0.5-78-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 vec
version:              0.5
visibility:           public
id:                   vec-0.5-7ABRPXJJy2cAIIwegqsvdg
key:                  vec-0.5-7ABRPXJJy2cAIIwegqsvdg
license:              BSD-3-Clause
copyright:            (c) 2017-2021 Oleg Grenrus
maintainer:           Oleg.Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/vec
synopsis:             Vec: length-indexed (sized) list
description:
    This package provides length-indexed (sized) lists, also known as vectors.

    @
    data Vec n a where
    \    VNil  :: Vec '\''Nat.Z a
    \    (:::) :: a -> Vec n a -> Vec ('\''Nat.S n) a
    @

    The functions are implemented in four flavours:

    * __naive__: with explicit recursion. It'\''s simple, constraint-less, yet slow.

    * __pull__: using @Fin n -> a@ representation, which fuses well,
    but makes some programs hard to write. And

    * __data-family__: which allows lazy pattern matching

    * __inline__: which exploits how GHC dictionary inlining works, unrolling
    recursion if the size of '\''Vec'\'' is known statically.

    As best approach depends on the application, @vec@ doesn'\''t do any magic
    transformation. Benchmark your code.

    This package uses [fin](https://hackage.haskell.org/package/fin), i.e. not @GHC.TypeLits@, for indexes.

    For @lens@ or @optics@ support see [vec-lens](https://hackage.haskell.org/package/vec-lens) and [vec-optics](https://hackage.haskell.org/package/vec-optics) packages respectively.

    See [Hasochism: the pleasure and pain of dependently typed haskell programming](https://doi.org/10.1145/2503778.2503786)
    by Sam Lindley and Conor McBride for answers to /how/ and /why/.
    Read [APLicative Programming with Naperian Functors](https://doi.org/10.1007/978-3-662-54434-1_21)
    by Jeremy Gibbons for (not so) different ones.

    === Similar packages

    * [linear](https://hackage.haskell.org/package/linear) has '\''V'\'' type,
    which uses '\''Vector'\'' from @vector@ package as backing store.
    @Vec@ is a real GADT, but tries to provide as many useful instances (upto @lens@).

    * [vector-sized](https://hackage.haskell.org/package/vector-sized)
    Great package using @GHC.TypeLits@. Current version (0.6.1.0) uses
    @finite-typelits@ and @Int@ indexes.

    * [sized-vector](https://hackage.haskell.org/package/sized-vector) depends
    on @singletons@ package. @vec@ isn'\''t light on dependencies either,
    but try to provide wide GHC support.

    * [fixed-vector](https://hackage.haskell.org/package/fixed-vector)

    * [sized](https://hackage.haskell.org/package/sized) also depends
    on a @singletons@ package. The @Sized f n a@ type is generalisation of
    @linear@'\''s @V@ for any @ListLike@.

    * [clash-prelude](https://hackage.haskell.org/package/clash-prelude)
    is a kitchen sink package, which has @CLaSH.Sized.Vector@ module.
    Also depends on @singletons@.

category:             Data, Dependent Types
abi:                  b007ad51ff504b2ea86a065ee59ff259
exposed:              True
exposed-modules:
    Data.Vec.DataFamily.SpineStrict Data.Vec.Lazy Data.Vec.Lazy.Inline
    Data.Vec.Pull

hidden-modules:       Control.Lens.Yocto SafeCompat
import-dirs:          /usr/lib/ghc-9.2.8/site-local/vec-0.5
library-dirs:         /usr/lib/ghc-9.2.8/site-local/vec-0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vec
hs-libraries:         HSvec-0.5-7ABRPXJJy2cAIIwegqsvdg
depends:
    QuickCheck-2.14.3-4RnDMHKDhpPJEbozrkRwOm
    adjunctions-4.4.2-34my02WcYQT98vNTGA1J6Q base-4.16.4.0
    boring-0.2.1-4ay7NZ1mR0V485tuSNtr0u deepseq-1.4.6.1
    distributive-0.6.2.1-LhvE64mkcRI8cPB2DAz4ot
    fin-0.3-LuyLfS5vPV19xhbR62jFbZ
    hashable-1.4.4.0-EsPTAmPpYqX3hovcHlHOLX
    indexed-traversable-0.1.4-2elnsjZhi4wA3U7RB4qSBi
    semigroupoids-6.0.0.1-LPryf0Uf1Lz9sQmpdLH8A2 transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-vec/html/vec.haddock
haddock-html:         /usr/share/doc/haskell-vec/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
